
notebook and javascript
=======================

.. contents::
    :local:
    :depth: 2

helpers
+++++++

.. autosignature:: jyquickhelper.helper_in_notebook.load_extension

.. autosignature:: jyquickhelper.helper_in_notebook.set_notebook_name_theNotebook

javascript
++++++++++

.. contents::
    :local:

.. autosignature:: jyquickhelper.helper_in_notebook.add_notebook_menu

.. autosignature:: jyquickhelper.json_helper.JSONJS

.. autosignature:: jyquickhelper.javascript_helper.RenderJS
    :members:

.. autosignature:: jyquickhelper.javascript_helper.RenderJSObj
    :members:
